@@ -8,6 +8,7 @@ import platform
 import re
 import socket
 import subprocess
+import time
 
 MAC_ADDR_PREFIX = [
     "B8:27:EB",
@@ -35,8 +36,12 @@ def ping(ip):
     prefix = ip.rsplit(".", maxsplit=1)[0]
 
     with open(os.devnull, mode="w") as devnull:
-        for x in range(0x1, 0xff):
-            subprocess.Popen(f"ping {prefix}.{x}", shell=True, stdout=devnull, stderr=devnull).kill()
+        processes = [subprocess.Popen(f"ping {prefix}.{x}", shell=True, stdout=devnull, stderr=devnull)
+                     for x in range(0x1, 0xff)]
+
+    time.sleep(1)
+    for process in processes:
+        process.terminate()
 
 
 def get_raspberry_pi():
